/****************************************
 * Gulp Task Configuration
 * --------------------------------------
 *
 * @author Christopher B. Dowell
 */
'use strict';

var utils                                           = require('../utils/utils.js');
var globals                                         = require('../globals.js');

var srcDir                                          = 'src';
var buildDir                                        = 'build';

var assetSubDir                                     = 'assets';
var assetSrcDir                                     = utils.addPath( srcDir, assetSubDir );
var assetBuildDir                                   = utils.addPath( buildDir, assetSubDir );

var svgSubDir                                       = 'svg';
var svgFileGlob                                     = '**/*.svg';
var svgSrcDir                                       = utils.addPath( assetSrcDir, svgSubDir );
var svgSrcPath                                      = utils.addPath( svgSrcDir, svgFileGlob );
var svgBuildDir                                     = utils.addPath( assetBuildDir, svgSubDir );
var svgBuildFile                                    = 'sprite.svg'
var svgBuildFilePath                                = utils.addPath( svgBuildDir, svgBuildFile );

var templateSubDir                                  = 'templates';
var templateSrcDir                                  = utils.addPath( assetSrcDir, templateSubDir );
var templateSrcFile                                 = 'sprite-template.scss';
var templateSrcPath                                 = utils.addPath( templateSrcDir, templateSrcFile );

var sassSubDir                                      = 'sass';
var sassSrcDir                                      = utils.addPath( assetSrcDir, sassSubDir );
var spriteSassFile                                  = '_sprite.scss';
var spriteSassFilePath                              = utils.addPath( sassSrcDir, spriteSassFile );

var imageSubDir                                     = 'images';
var imageSrcDir                                     = utils.addPath( assetSrcDir, imageSubDir );
var imageBuildDir                                   = utils.addPath( assetBuildDir, imageSubDir );

module.exports = {

    getSrcDir: function() {
        return globals.src;
    },

    getBuildDir: function() {
        return globals.build;
    },

    'default': {
        taskDependsList                             : [ 'serve' ]
    },

    serve: {
        taskDependsList                             : [ 'browser-sync' ]
    },

    browserSync: {
        taskDependsList                             : [ 'watch' ],
        baseDir                                     : buildDir
    },

    watch: {

    },

    clean: {
        paths                                       : buildDir 
    },

    svgSprite: {
        srcPaths                                    : svgSrcPath,
        buildDir                                    : '.',
        svgSpritePluginOptions: {
            mode: {
                css: {
                    spacing: {
                        padding                     : 5
                    },
                    dest                            : '.',
                    layout                          : 'diagonal',
                    sprite                          : svgBuildFilePath,
                    bust                            : false,
                    render: {
                        scss: {
                            dest                    : spriteSassFilePath,
                            template                : templateSrcPath
                        }
                    }
                }
            }
        }
    },

    svg2png: {
        taskDependsList                             : [ 'svg-sprite' ],
        srcPaths                                    : 'src/assets/svg/icons/*.svg',
        buildDir                                    : 'build/assets/icons/'
    },

    iconFonts: {
        srcPaths                                    : 'src/assets/svg/**/*.svg',
        buildDir                                    : 'build/assets/fonts/icons',
        iconFontPluginOptions: {
            fontName                                : 'dynaware-icons',
            appendCodepoints                        : true
        }
    },

    svgSymbols: {
        srcPaths                                    : 'src/assets/svg/**/*.svg',
        buildDir                                    : 'build/assets/icons/',
        svgSymbolsPluginOptions: {
            className                               : '.icon-%f',
            title                                   : false
        }
    },

    svgStore: {
        srcPaths                                    : 'src/assets/svg/**/*.svg',
        buildDir                                    : 'build',
        injectSrcFilePath                           : 'src/index.html',
        svgStorePluginOptions: {
            inlineSvg                               : true
        }
    }

}