/****************************************
 * Gulp Task: svg-2-png
 * --------------------------------------
 *
 * Converts SVG files to PNG for fallback
 *
 * @author Christopher B. Dowell
 */
'use strict';

var gulp            = require( 'gulp' );
var config          = require( '../../config/config' );

var plugins         = require( 'gulp-load-plugins' )({
                        pattern: [ 'gulp-*', 'gulp.*' ],
                        replaceString: /\bgulp[\-.]/
                    });

gulp.task( 'svgs:png', config.taskDependsList, function () {

    return gulp.src( config.srcPaths )

        .pipe( plugins.svg2png() )

        .pipe( gulp.dest( config.buildDir ) );

});

gulp.task( 'svgs:symbols', function () {

    return gulp.src( config.srcPaths )

        .pipe( plugins.svgSymbols( config.svgSymbolsPluginOptions ) )

        .pipe( gulp.dest( config.buildDir ) );

});

gulp.task( 'svgs:store', function () {
    
    var svgs = gulp.src( config.srcPaths )

        .pipe( plugins.svgmin() )
        
        .pipe( plugins.svgstore( config.svgStorePluginOptions ));


    function fileContents ( filePath, file ) {
        return file.contents.toString();
    }

    return gulp.src( config.injectSrcFilePath )

        .pipe( plugins.inject( svgs, { transform: fileContents }))

        .pipe( gulp.dest( config.buildDir ) );

});

gulp.task( 'svgs:sprite', function () {

    return gulp.src( config.srcPaths )

        .pipe( plugins.svgo() )

        .pipe( plugins.svgSprite( config.svgSpritePluginOptions ))

        .pipe( plugins.size())

        .pipe( gulp.dest( config.buildDir ) );

});